Index: src/gpu/gl/GrGLProgram.cpp |
diff --git a/src/gpu/gl/GrGLProgram.cpp b/src/gpu/gl/GrGLProgram.cpp |
index 6e9878a91949873a0b69bb113d65888c9ce0f2d7..9b997c85ec6587c909887c9e9c67131ace90f490 100644 |
--- a/src/gpu/gl/GrGLProgram.cpp |
+++ b/src/gpu/gl/GrGLProgram.cpp |
@@ -229,10 +229,11 @@ void GrGLProgram::setData(GrDrawState::BlendOptFlags blendOpts, |
fCoverageEffects->setData(fGpu, fUniformManager, coverageStages); |
// TexGen state applies to the the fixed function vertex shader. For custom shaders, it's |
// ignored, so we don't need to change the texgen settings in that case. |
if (!fHasVertexShader) { |
- fGpu->flushTexGenSettings(fNumTexCoordSets); |
+ fGpu->flushPathTexGenSettings(fNumTexCoordSets); |
} |
} |
@@ -229,10 +229,11 @@ void GrGLProgram::setData(GrDrawState::BlendOptFlags blendOpts, |
fCoverageEffects->setData(fGpu, fUniformManager, coverageStages); |
- // TexGen state applies to the the fixed function vertex shader. For custom shaders, it's |
- // ignored, so we don't need to change the texgen settings in that case. |
+ // PathTexGen state applies to the the fixed function vertex shader. For |
+ // custom shaders, it's ignored, so we don't need to change the texgen |
+ // settings in that case. |
if (!fHasVertexShader) { |